@@ -86,7 +86,7 @@ BAD_WORDS = ['okay','kinda','w','even','only','really','maybe','being','having',
             'does','four','might','ten','hum','six','once','either','eight','both','ah','o','d','myself','u',
             'ones','seven','huh','s','nine','few','thousand','anybody','somebody','everybody','hafta','someone',
             'yep','hey','anymore','kinda','seventy','yet','against','anyway','forty','ninety','wow','gotta',
-            'such','somewhere','may','bush','gore','there','very','back','ever']
+            'such','somewhere','may','bush','gore','there','very','back','ever','q','x','ex']
 MONOPHTHONGS = ['aa','ae','eh','ey','ih','iy','ow','uh','uw']
 
 class WTManager(BulkManager):
@@ -679,10 +679,11 @@ class WordToken(caching.base.CachingMixin,models.Model):
             prev_context = self.getPreviousContext(window = int(window))
         else:
             prev_context = self.getPreviousContext()
-        prev_context = filter(lambda x: x is not None,[ x.get_sense(disambiguate=disambiguate) for x in prev_context])
+        prev_context = filter(lambda x: x is not None,[ x.get_sense(disambiguate=disambiguate) for x in prev_context if str(x) != str(self)])
+
         sense = self.get_sense(disambiguate=disambiguate)
         if sense is None:
-            return None
+            return 'NA'
         sp = SEM_PRED.get_semantic_predictability(sense,prev_context,style=style)
         if style == 'A' and window == 'A':
             self.PrevSemPred = sp
@@ -697,7 +698,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
             foll_context = self.getFollowingContext(window = int(window))
         else:
             foll_context = self.getFollowingContext()
-        foll_context = filter(lambda x: x is not None,[ x.get_sense(disambiguate=disambiguate) for x in foll_context])
+        foll_context = filter(lambda x: x is not None,[ x.get_sense(disambiguate=disambiguate) for x in foll_context if str(x) != str(self)])
         sense = self.get_sense(disambiguate=disambiguate)
         if sense is None:
             return None
